#
# spec file for package vnote
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vnote
Version:        3.10.1
Release:        1.13
Summary:        A Vim-inspired note-taking application, especially for Markdown
License:        LGPL-3.0-only
Group:          Productivity/Text/Editors
URL:            https://github.com/tamlok/vnote
Source0:        https://github.com/tamlok/vnote/archive/v%{version}.tar.gz#/vnote-%{version}.tar.gz
Source1:        vtextedit-08b440d.zip
Source2:        hunspell-efb0389.zip
Source3:        sonnet-403863f.zip
Source4:        syntax-highlighting-807895f.zip
BuildRequires:  libqt5-qtbase-devel >= 5.12
BuildRequires:  libqt5-qtsvg-devel
BuildRequires:  libqt5-qtwebengine-devel
BuildRequires:  unzip
BuildRequires:  update-desktop-files
Recommends:     libssl44
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
VNote is a note-taking application, designed especially for Markdown.
VNote provides both note management and Markdown edit experience.

%package -n libVSyntaxHighlighting1
Summary:        Library files for vnote
Group:          System/Libraries

%description -n libVSyntaxHighlighting1
This package provides library files for vnote.

%package -n libVTextEdit1
Summary:        Library files for vnote
Group:          System/Libraries

%description -n libVTextEdit1
This package provides library files for vnote.

%prep
%setup -q

cd libs
rm -r vtextedit
unzip %{_sourcedir}/vtextedit-08b440d.zip
mv vtextedit-* vtextedit

cd vtextedit/src/libs
rm -r hunspell sonnet syntax-highlighting
unzip %{_sourcedir}/hunspell-efb0389.zip
mv hunspell-* hunspell
unzip %{_sourcedir}/sonnet-403863f.zip
mv sonnet-* sonnet
unzip %{_sourcedir}/syntax-highlighting-807895f.zip
mv syntax-highlighting-* syntax-highlighting

%build
mkdir build && cd build
qmake-qt5 QMAKE_CFLAGS+="%{optflags}" QMAKE_CXXFLAGS+="%{optflags}" QMAKE_STRIP="/bin/true" ../vnote.pro
make %{?_smp_mflags}

%install
cd build
make install INSTALL_ROOT="%{buildroot}"
rm %{buildroot}%{_prefix}/lib/libVSyntaxHighlighting.so
rm %{buildroot}%{_prefix}/lib/libVTextEdit.so
%suse_update_desktop_file -r vnote Utility TextEditor

%post -n libVSyntaxHighlighting1 -p /sbin/ldconfig
%postun -n libVSyntaxHighlighting1 -p /sbin/ldconfig

%post -n libVTextEdit1 -p /sbin/ldconfig
%postun -n libVTextEdit1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/vnote
%{_bindir}/vnote_extra.rcc
%{_datadir}/applications/vnote.desktop
%{_datadir}/icons/hicolor
%doc README.md changes.md
%license COPYING.LESSER

%files -n libVSyntaxHighlighting1
%{_prefix}/lib/libVSyntaxHighlighting.so*

%files -n libVTextEdit1
%{_prefix}/lib/libVTextEdit.so*

%changelog
* Sat Dec  4 2021 Grover Chou <groverchout@opensuse.org>
- update to version v3.10.1
- for more details please visit https://github.com/vnotex/vnote/releases
* Sat Sep  5 2020 xia lei <emricg2@gmail.com>
- update to version v2.10
  * Add simple support for Git sync including push and pull.
  You need to install Git and execute git init under the root of your notebook
  root folder first.
* Sun Feb 16 2020 Grover Chou <groverchout@gmail.com>
- update to version v2.8.2
  * Upgrade Mermaid.js to latest release
  * Fix PlantUML online resources
  * Add a configuration in Settings to control code block copy button
  * Add supports for image hosting, including service GitHub, Gitee, Wechat, and Tencent Cloud
  * Support sorting notebooks in context menu
  * Add theme v_next
* Mon Jun 24 2019 Grover Chou <groverchout@gmail.com>
- update to version v2.7
  * Editor: Fix smart table bugs; Fix improper leading line space on macOS;
  * Fix bug which will open two tabs for the same file;
  * Add copy button to copy code block in read mode;
  * PluatUML: use shell to launch Java;
  * Use qt 5.12.1 on macOS for better performance;
  * Add theme v_simple provided by user LuoshuiTianyi;
  * Support adding sibling folder in context menu;
- For more details please visit https://github.com/tamlok/vnote/releases/tag/v2.7
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrailty of descriptions. Trim metadata redundancies.
* Thu May 16 2019 Grover Chou <groverchout@gmail.com>
- update to version v2.5
* Fri Oct  5 2018 Ching-Yat Foo <tsingyat@outlook.com> 2.0
- update to version v2.0
- for more details please visit https://github.com/tamlok/vnote/releases/tag/v2.0
* Sun Aug  5 2018 groverchout@gmail.com
- update to version v1.20
- For more details please visit https://github.com/tamlok/vnote/releases/tag/v1.20
* Tue May  1 2018 groverchout@gmail.com
- update to version v1.15
  * Support PlantUML and Graphviz
  * In-Place Preview for MathJax and Diagrams
  * Live-Preview for Diagrams
  * Embedding Images in Exported HTML
  * Others
- For more details please visit https://github.com/tamlok/vnote/releases/tag/v1.15
* Tue Apr  3 2018 groverchout@gmail.com
- update to version v1.14, for more details please visit https://github.com/tamlok/vnote/releases/
  tag/v1.14
* Sun Mar 25 2018 groverchout@gmail.com
- update to version v1.13, for more details please visit https://github.com/tamlok/vnote/releases/tag/v1.13
* Fri Mar  2 2018 groverchout@gmail.com
- Combine EditNote and SaveExitNote as EditReadNote (Ctrl+T);
- Support exporting notes as Markdown, HTML, and PDF;
- Support simple search in directory tree, file list, and outline;
- Support copying selected text as HTML in edit mode;
- Support copying text to Evernote, OneNote, Word, WeChat Public Account editor and so on;
- Support auto-save;
- Support fullscreen mode and hiding menu bar;
- Support Ctrl+H/W/U to delete text in most line edits;
- Support zooming in/out in edit mode;
- Support MathJax in fenced code block with language mathjax specified;
- More shortcuts;
- Add Cart to collect notes for further processing;
- Output built-in themes on start of VNote;
- Esc to exit edit mode when Vim mode is disabled;
- Support Vim command line for search in read mode;
- Support printing;
- Single click in file list to open file in current tab, double clicks to open in a new tab;
* Wed Dec 20 2017 groverchout@gmail.com
- Support themes;
  * Three built-in mordern themes;
  * One dark mode theme;
- Vim mode
  * Support block cursor in Normal/Visual mode;
  * = to auto-indent selected lines as the first line;
- Support custom external editors to open notes;
- Enable Ctrl+C/Ctrl+V in Vim mode to copy/paste;
- Support Flash Page to record ideas quickly;
- Support previewing inline images;
* Sun Nov 19 2017 groverchout@gmail.com
- Migrate to Qt 5.9.1;
- Support Compact mode in main window;
- Update icons;
- Support custom startup pages;
- Remove obsolete title marker when inserting new one;
- Support Magic Words;
- Vim mode
  * Share registers among all tabs;
  * Support Ctrl+O in Insert mode;
- Add "Code Block", "Insert Link", and "Insert Image" tool bar buttons;
- Support Ctrl+Shift+T to recover last closed tabs;
- Support view read-only files in edit mode;
- Refactor editor for speed;
- Support templates when creating notes;
- Support snippets;
- Support file change check;
- Support backup file (save changes automatically);
* Fri Nov 17 2017 groverchout@gmail.com
- bug fixes
* Thu Nov 16 2017 groverchout@gmail.com
- update vnote v1.9
- for more information please visit https://github.com/tamlok/vnote/releases/tag/v1.9
